@@ -11,7 +11,7 @@ setup(
     description="A tool for integrating upstream mods into Portmod",
     license="GPLv3",
     url="https://gitlab.com/portmod/importmod",
-    packages=find_packages(include=["importmod_core.*"]),
+    packages=find_packages(include=["importmod_core"]),
     entry_points=({"console_scripts": ["importmod = importmod_core.main:main"]}),
     install_requires=["tomlkit", "prompt_toolkit"],
     setup_requires=["setuptools_scm"],
