@@ -119,6 +119,8 @@ def update_idir(idir: AtomtrailersNode, new_idir: InstallDir):
                             RedBaron(pending_files[file].comment)
                         )
                         list_for_key.node_list.append(RedBaron("\n"))
+                    # Attribute may be present but empty
+                    if hasattr(pending_files[file], "comment"):
                         del pending_files[file].comment
                     list_for_key.node_list.append(
                         RedBaron(str(pending_files[file]) + ",")
@@ -829,9 +831,13 @@ def generate_pybuild(
             update_idir(dirs[0], INSTALL_DIRS[0])
         else:
             pending_dirs = {
-                os.path.join(d.S, d.PATH): d for d in INSTALL_DIRS if d.S is not None
+                os.path.join(d.S, d.PATH): d
+                for d in INSTALL_DIRS
+                if getattr(d, "S", None)
             }
-            pending_dirs.update({d.PATH: d for d in INSTALL_DIRS if d.S is None})
+            pending_dirs.update(
+                {d.PATH: d for d in INSTALL_DIRS if getattr(d, "S", None) is None}
+            )
             for node in dirs:
                 if isinstance(node, AtomtrailersNode):
                     # Install dirs are identified uniquely by their source and first
@@ -865,12 +871,26 @@ def generate_pybuild(
                 if new_dir.comment:
                     dirlist.node_list.append(RedBaron(new_dir.comment))
                     dirlist.node_list.append(RedBaron("\n"))
-                    del new_dir.comment
+
+                del new_dir.comment
                 dirlist.value.append(RedBaron(str(new_dir)))
 
     else:
         if INSTALL_DIRS:
-            Mod.append(f'INSTALL_DIRS = [{", ".join(f"{d}" for d in INSTALL_DIRS)}]')
+
+            def format_installdir(idir):
+                if idir.comment:
+                    result = f"# {idir.comment}" + "\n" + f"{idir}"
+                else:
+                    result = f"{idir}"
+                del idir.comment
+                return result
+
+            Mod.append(
+                "INSTALL_DIRS = [\n"
+                + ",\n".join(format_installdir(d) for d in INSTALL_DIRS)
+                + "\n]"
+            )
 
     build_file: str = pybuild.dumps()
 
