@@ -5,9 +5,10 @@
 
 import requests
 from bs4 import BeautifulSoup
+from portmodlib.source import Source
 
 from ..atom import parse_version
-from . import PackageSource
+from . import PackageData, PackageSource
 
 
 class ModhistorySource(PackageSource):
@@ -24,6 +25,21 @@ class ModhistorySource(PackageSource):
     def __hash__(self):
         return hash(self.id)
 
+    def get_pkg_data(self, package: PackageData):
+        package.homepage = self.get_url()
+        package.sources = [
+            Source(f"http://mw.modhistory.com/file.php?id={self.id}", package.atom.P)
+        ]
+        package.src_uri = (
+            f"http://mw.modhistory.com/file.php?id={self.id} -> {package.atom.P}"
+        )
+        info = get_modhistory_info(self.get_url())
+
+        package.name = info["title"]
+        package.authors.append(info["author"])
+        package.update_atom(version=info["Version"])
+        return package
+
 
 def get_modhistory_info(url):
     """
@@ -44,4 +60,9 @@ def get_modhistory_info(url):
             title = info[0].string.rstrip(":")
             value = info[1].string
             data[title] = value
+    for author_elem in soup.find_all("p", class_="author"):
+        data["author"] = author_elem.text
+
+    for title in soup.find_all("h2", class_="cattitle"):
+        data["title"] = title.string
     return data
