@@ -4,26 +4,10 @@ import shlex
 import shutil
 import subprocess
 from shutil import rmtree, which
-from typing import Tuple
 
 from portmod.globals import env
+from portmodlib._deprecated.vfs import find_file
 from portmodlib.masters import get_masters
-from portmodlib.vfs import find_file
-
-
-class NotDDSException(Exception):
-    """Exception indicating that the given file was not a DDS file"""
-
-
-def get_texture_size(path: str) -> Tuple[int, int]:
-    """Determines the texture size of the given dds file"""
-    with open(path, mode="rb") as file:
-        buffer = file.read(24)
-        if buffer[0:4] != bytes([0x44, 0x44, 0x53, 0x20]):
-            raise NotDDSException("{} is not a DDS file!".format(path))
-        height = buffer[12:16]
-        width = buffer[16:20]
-    return int.from_bytes(height, "little"), int.from_bytes(width, "little")
 
 
 def tr_patcher(filename: str):
