@@ -5,8 +5,8 @@ import urllib.parse
 from logging import debug, error
 
 from portmod.loader import load_all
-from portmod.parsers.usestr import use_reduce
 from portmod.source import HashAlg
+from portmodlib.usestr import use_reduce
 
 from .sources.nexus import parse_nexus_url, validate_file
 
